@@ -1,17 +1,19 @@
-#' Print method for \code{ao}
+#' Print method for an object of class \code{ao}.
+#' @description
+#' This function is the print method for an object of class \code{ao}.
 #' @param x
 #' The output of \code{\link{ao}}, which is an object of class \code{ao}.
 #' @param ...
-#' ignored
+#' Ignored.
 #' @export
 
 print.ao = function(x,...) {
   cat("Alternating optimization\n")
   cat(if(x$minimize) "Minimum value:",
       if(!x$minimize) "Maximum value:",
-      x$optimum,"\n")
+      zapsmall(x$optimum),"\n")
   cat(if(x$minimize) "Minimum at:",
       if(!x$minimize) "Maximum at:",
-      x$estimate,"\n")
+      zapsmall(x$estimate),"\n")
   cat("computation time:",signif(x$time,digits=1),"seconds\n")
 }
